use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Bohne
David
Exception
Getopt
Golden
James
Keenan
Kevin
Lucid
McGrath
Nova
Patch
Precious
Robert
dagolden
davidp
getopt
jkeenan
keypair
keypairs
kmcgrath
lib
param
patch
rbo
thilp
xdg
